@@ -7,10 +7,11 @@ def utcnow() -> datetime:
 
 def aware(naive='now', tz='UTC'):
     '''accepts a tuple, list, timestamp (s, ms, us or ns) aware or naive datetime
-    returns tz aware datetime. 
+    returns tz aware datetime.
+    naive datetimes are considered UTC
     Lists and tuples are only accepted in UTC and can be converted to TZ
     Aware datetimes will be CONVERTED to TZ'''
-    if naive == 'now':
+    if naive in [None, 'now']:
         return utcnow().astimezone(pytz.timezone(tz))
     elif isinstance(naive,(tuple, list)):
         return pytz.timezone('UTC').localize(datetime(*naive)).astimezone(pytz.timezone(tz))
@@ -28,3 +29,17 @@ def aware(naive='now', tz='UTC'):
             return pytz.timezone('UTC').localize(naive).astimezone(pytz.timezone(tz))
         else:
             return naive.astimezone(pytz.timezone(tz))
+
+def my_sql_dt_format(dt='now'):
+    """
+    accepts the same params as aware
+    gets the aware datetime
+    transformes it into UTC
+    returns the dtstring in the fomat necessary for the mysql datetime object
+    """
+    dt = aware(dt)
+    return dt.strftime('%Y-%m-%d %H:%M:%S')
+    
+
+if __name__ == '__main__':
+    print(my_sql_dt_format())
\ No newline at end of file
